"""Implementation of text fixer tool."""
import string


class TextFixerWorker:
    """Class implementing TextFixerWorker worker."""

    def __init__(self, dataset_file):
        """Constructor.

        :param dataset_file: path to dataset file
        :type dataset_file: str
        """
        with open(dataset_file, 'r') as f:
            self.polish_word_dataset = set(f.read().splitlines())

    def word_transfer(self, text):
        """Method to check word transfer.

        Method check if last word in line and first word in next line in
        polish word dataset.

        :param text: input text to be fixed
        :type text: list
        :return: fixed text
        :rtype: str
        """
        flag = 0
        clean_text = []
        for counter, line in enumerate(text):
            line = line.strip()
            if flag == 1:
                if not line.split(' ')[1:]:
                    continue
                line = line.split(' ')[1:]
                line = ' '.join(line)
                flag = 0
            if len(text) == counter + 1:
                clean_text.append(line)
            elif line != '':
                word = line.split(' ')[-1] + text[counter + 1].split(' ')[0]
                words_without_punctuation = word.translate(
                    str.maketrans('', '', string.punctuation + '„”-'))
                if words_without_punctuation.lower() in\
                        self.polish_word_dataset:
                    if '-' in word:
                        sentence = ' '.join(line.split(' ')[:-1] +
                                            [word.replace('-', '')])
                    else:
                        sentence = ' '.join(line.split(' ')[:-1] + [word])
                    clean_text.append(sentence)
                    flag = 1
                else:
                    clean_text.append(line)
            else:
                clean_text.append(line)
        return '\n'.join(clean_text)
